@@ -6,16 +6,16 @@ use Carp;
 use File::ShareDir ':ALL';
 use Path::Tiny;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 has admin_menu => sub {
   my $self = shift;
-  return +{};
+  return [];
 };
 
 has frontend_menu => sub {
   my $self = shift;
-  return +{};
+  return [];
 };
 
 sub startup {
