@@ -2,6 +2,7 @@ package App::skryf::Plugin::Admin::Controller;
 
 use Mojo::Base 'Mojolicious::Controller';
 use Method::Signatures;
+use App::skryf::Model::User;
 
 method admin_dashboard {
     $self->render('admin/dashboard');
@@ -9,7 +10,7 @@ method admin_dashboard {
 
 method admin_dashboard_profile {
     my $req   = $self->req->method;
-    my $model = $self->db('User');
+    my $model = App::skryf::Model::User->new;
     my $user  = $model->get($self->session->{username});
     if ($req eq "POST") {
         $user->{attrs}{email}              = $self->param('email');
