@@ -29,11 +29,11 @@ __END__
 
 =head1 NAME
 
-App::skryf::Plugin::Search - Mojolicious Plugin
+App::skryf::Plugin::Search - Skryf Plugin
 
 =head1 DESCRIPTION
 
-L<App::skryf::Plugin::Search> is a L<Mojolicious> plugin.
+L<App::skryf::Plugin::Search> is a L<App::skryf> plugin.
 
 =head1 METHODS
 
@@ -46,15 +46,20 @@ L<Mojolicious::Plugin> and implements the following new ones.
 
 Register plugin in L<Mojolicious> application.
 
+=head1 AUTHOR
+
+Adam Stokes E<lt>adamjs@cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2013- Adam Stokes
+
+=head1 LICENSE
+
+Licensed under the same terms as Perl.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
 
-=head1 COPYRIGHT AND LICENSE
-
-This plugin is copyright (c) 2013 by Adam Stokes <adamjs@cpan.org>
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
